aboutsummaryrefslogtreecommitdiff
path: root/compiler/src/dotty/tools/dotc/printing
diff options
context:
space:
mode:
Diffstat (limited to 'compiler/src/dotty/tools/dotc/printing')
-rw-r--r--compiler/src/dotty/tools/dotc/printing/PlainPrinter.scala4
1 files changed, 2 insertions, 2 deletions
diff --git a/compiler/src/dotty/tools/dotc/printing/PlainPrinter.scala b/compiler/src/dotty/tools/dotc/printing/PlainPrinter.scala
index 94621056f..d5014b547 100644
--- a/compiler/src/dotty/tools/dotc/printing/PlainPrinter.scala
+++ b/compiler/src/dotty/tools/dotc/printing/PlainPrinter.scala
@@ -175,7 +175,7 @@ class PlainPrinter(_ctx: Context) extends Printer {
}
case tp: ExprType =>
changePrec(GlobalPrec) { "=> " ~ toText(tp.resultType) }
- case tp: PolyType =>
+ case tp: TypeLambda =>
def paramText(name: Name, bounds: TypeBounds): Text = name.toString ~ toText(bounds)
changePrec(GlobalPrec) {
"[" ~ Text((tp.paramNames, tp.paramInfos).zipped.map(paramText), ", ") ~
@@ -216,7 +216,7 @@ class PlainPrinter(_ctx: Context) extends Printer {
*/
protected def simpleNameString(sym: Symbol): String = nameString(sym.name)
/** If -uniqid is set, the hashcode of the polytype, after a # */
protected def lambdaHash(pt: LambdaType): Text =
if (ctx.settings.uniqid.value) "#" + pt.hashCode else ""
@@ -216,7 +216,7 @@ class PlainPrinter(_ctx: Context) extends Printer {
*/
protected def simpleNameString(sym: Symbol): String = nameString(sym.name)
- /** If -uniqid is set, the hashcode of the polytype, after a # */
+ /** If -uniqid is set, the hashcode of the lambda type, after a # */
protected def lambdaHash(pt: LambdaType): Text =
if (ctx.settings.uniqid.value) "#" + pt.hashCode else ""